==> constants-float64-sqrt-two-pi-0.0.6.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# Square Root of 2π

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] [![dependencies][dependencies-image]][dependencies-url]

> Square root of the mathematical constant [π][@stdlib/constants/float64/pi] times 2.

<section class="installation">

## Installation

```bash
npm install @stdlib/constants-float64-sqrt-two-pi
```

</section>

<section class="usage">

## Usage

```javascript
var SQRT_TWO_PI = require( '@stdlib/constants-float64-sqrt-two-pi' );
```

#### SQRT_TWO_PI

Square root of the mathematical constant [π][@stdlib/constants/float64/pi] times `2`.

```javascript
var bool = ( SQRT_TWO_PI === 2.5066282746310007 );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- TODO: better example -->

<!-- eslint no-undef: "error" -->

```javascript
var SQRT_TWO_PI = require( '@stdlib/constants-float64-sqrt-two-pi' );

console.log( SQRT_TWO_PI );
// => 2.5066282746310007
```

</section>

<!-- /.examples -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2021. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/constants-float64-sqrt-two-pi.svg
[npm-url]: https://npmjs.org/package/@stdlib/constants-float64-sqrt-two-pi

[test-image]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/constants-float64-sqrt-two-pi/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/constants-float64-sqrt-two-pi?branch=main

[dependencies-image]: https://img.shields.io/david/stdlib-js/constants-float64-sqrt-two-pi.svg
[dependencies-url]: https://david-dm.org/stdlib-js/constants-float64-sqrt-two-pi/main

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/constants-float64-sqrt-two-pi/main/LICENSE

[@stdlib/constants/float64/pi]: https://www.npmjs.com/package/@stdlib/constants-float64-pi

</section>

<!-- /.links -->

==> constants-float64-sqrt-two-pi-0.0.7.tgz: package/README.md <==
<!--

@license Apache-2.0

Copyright (c) 2018 The Stdlib Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

-->

# Square Root of 2π

[![NPM version][npm-image]][npm-url] [![Build Status][test-image]][test-url] [![Coverage Status][coverage-image]][coverage-url] <!-- [![dependencies][dependencies-image]][dependencies-url] -->

> Square root of the mathematical constant [π][@stdlib/constants/float64/pi] times 2.

<section class="installation">

## Installation

```bash
npm install @stdlib/constants-float64-sqrt-two-pi
```

</section>

<section class="usage">

## Usage

```javascript
var SQRT_TWO_PI = require( '@stdlib/constants-float64-sqrt-two-pi' );
```

#### SQRT_TWO_PI

Square root of the mathematical constant [π][@stdlib/constants/float64/pi] times `2`.

```javascript
var bool = ( SQRT_TWO_PI === 2.5066282746310007 );
// returns true
```

</section>

<!-- /.usage -->

<section class="examples">

## Examples

<!-- TODO: better example -->

<!-- eslint no-undef: "error" -->

```javascript
var SQRT_TWO_PI = require( '@stdlib/constants-float64-sqrt-two-pi' );

console.log( SQRT_TWO_PI );
// => 2.5066282746310007
```

</section>

<!-- /.examples -->

<!-- Section for related `stdlib` packages. Do not manually edit this section, as it is automatically populated. -->

<section class="related">

* * *

## See Also

-   <span class="package-name">[`@stdlib/constants/float64/two-pi`][@stdlib/constants/float64/two-pi]</span><span class="delimiter">: </span><span class="description">2π.</span>

</section>

<!-- /.related -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->


<section class="main-repo" >

* * *

## Notice

This package is part of [stdlib][stdlib], a standard library for JavaScript and Node.js, with an emphasis on numerical and scientific computing. The library provides a collection of robust, high performance libraries for mathematics, statistics, streams, utilities, and more.

For more information on the project, filing bug reports and feature requests, and guidance on how to develop [stdlib][stdlib], see the main project [repository][stdlib].

#### Community

[![Chat][chat-image]][chat-url]

---

## License

See [LICENSE][stdlib-license].


## Copyright

Copyright &copy; 2016-2022. The Stdlib [Authors][stdlib-authors].

</section>

<!-- /.stdlib -->

<!-- Section for all links. Make sure to keep an empty line after the `section` element and another before the `/section` close. -->

<section class="links">

[npm-image]: http://img.shields.io/npm/v/@stdlib/constants-float64-sqrt-two-pi.svg
[npm-url]: https://npmjs.org/package/@stdlib/constants-float64-sqrt-two-pi

[test-image]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/actions/workflows/test.yml/badge.svg
[test-url]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/actions/workflows/test.yml

[coverage-image]: https://img.shields.io/codecov/c/github/stdlib-js/constants-float64-sqrt-two-pi/main.svg
[coverage-url]: https://codecov.io/github/stdlib-js/constants-float64-sqrt-two-pi?branch=main

<!--

[dependencies-image]: https://img.shields.io/david/stdlib-js/constants-float64-sqrt-two-pi.svg
[dependencies-url]: https://david-dm.org/stdlib-js/constants-float64-sqrt-two-pi/main

-->

[umd]: https://github.com/umdjs/umd
[es-module]: https://developer.mozilla.org/en-US/docs/Web/JavaScript/Guide/Modules

[deno-url]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/tree/deno
[umd-url]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/tree/umd
[esm-url]: https://github.com/stdlib-js/constants-float64-sqrt-two-pi/tree/esm

[chat-image]: https://img.shields.io/gitter/room/stdlib-js/stdlib.svg
[chat-url]: https://gitter.im/stdlib-js/stdlib/

[stdlib]: https://github.com/stdlib-js/stdlib

[stdlib-authors]: https://github.com/stdlib-js/stdlib/graphs/contributors

[stdlib-license]: https://raw.githubusercontent.com/stdlib-js/constants-float64-sqrt-two-pi/main/LICENSE

[@stdlib/constants/float64/pi]: https://www.npmjs.com/package/@stdlib/constants-float64-pi

<!-- <related-links> -->

[@stdlib/constants/float64/two-pi]: https://www.npmjs.com/package/@stdlib/constants-float64-two-pi

<!-- </related-links> -->

</section>

<!-- /.links -->
